/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2014 Red Hat, Inc., and individual contributors
 * as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.modules;

/**
 * A module specification for a module alias.
 *
 * @author <a href="mailto:david.lloyd@redhat.com">David M. Lloyd</a>
 */
public final class AliasModuleSpec extends ModuleSpec {

    private final String aliasName;

    AliasModuleSpec(final String name, final String aliasName) {
        super(name);
        this.aliasName = aliasName;
    }

    /**
     * Get the module alias target.
     *
     * @return the module alias target
     * @deprecated Use {@link #getAliasName()} instead.
     */
    @Deprecated
    public ModuleIdentifier getAliasTarget() {
        return ModuleIdentifier.fromString(aliasName);
    }

    /**
     * Get the module alias name.
     *
     * @return the module alias name
     */
    public String getAliasName() {
        return aliasName;
    }

}
